Prints, in a readable manner, the main information from any of
the data frames containing power information from the list created by the
POSSA::pow function. This is an extension (method)
of the base R print function, so it can be called simply as
print().
# S3 method for possa_pow_df
print(x, round_to = 5, possa_title = TRUE, ...)Returns nothing (NULL); this method serves only to print
information to the console.
Power information data.frame included in the list
returned by the POSSA::pow function.
Number of fractional digits to round to, for the displayed
numbers (5 by default).
Set to FALSE to omit title printing.
(Allow additional arguments for technical reasons.)
pow, print.possa_pow_list