Prints, in a readable manner, the main information from the list
created by the POSSA::pow function, calling
print.possa_pow_df for each of the POSSA power information
data frames in the list. This is an extension (method) of the base R
print function, so it can be called simply as print().
# S3 method for possa_pow_list
print(x, round_to = NA, ...)Returns nothing (NULL); this method serves only to print
information to the console.
The list returned by the
POSSA::pow function.
Number of fractional digits to round to, for the displayed
numbers. The default is the value passed from the
POSSA::pow function (stored in the returned list).
(Allow additional arguments for technical reasons.)
pow, print.possa_pow_df